==> digikam-3.0.0-beta2.tar.bz2: digikam-3.0.0-beta2/extra/kipi-plugins/kioexportimport/kipiplugin_kioexportimport.desktop.cmake <==
[Desktop Entry]
Name=KioExportImport
Name[ast]=KioExportImport
Name[bg]=Изнасяне и внасяне през Kio
Name[bs]=Kio Izvoz Uvoz
Name[ca]=KioExportImport
Name[ca@valencia]=KioExportImport
Name[cs]=KioExportImport
Name[da]=KioExportImport
Name[de]=KioExportImport
Name[el]=KioExportImport
Name[en_GB]=KioExportImport
Name[es]=KioExportImport
Name[et]=KIO eksport-import
Name[eu]=KioExportImport
Name[fr]=Exportation/Importation Kio
Name[ga]=KioExportImport
Name[gl]=KioExportImport
Name[hu]=Kio exportálás-importálás
Name[is]=KioExportImport
Name[it]=Esportazione e importazione con KIO
Name[km]=KioExportImport
Name[lv]=KioExportImport
Name[nb]=KioExportImport
Name[nl]=KioExportImport
Name[pa]=KioExportImport
Name[pl]=EksportImportZKio
Name[pt]=KioExportImport
Name[pt_BR]=Exportar e importar pelo KIO
Name[ro]=Export/Import Kio
Name[ru]=Импорт и экспорт через KIO
Name[sk]=Kio export a import
Name[sl]=KioExportImport
Name[sv]=Export och import med I/O-slav
Name[th]=KioExportImport
Name[tr]=KioExportImport
Name[uk]=KioExportImport
Name[x-test]=xxKioExportImportxx
Name[zh_CN]=Kio 导入导出
Name[zh_TW]=Kio 匯出/匯入
Comment=A tool to export pictures to or import from a remote directory that is accessible via KIO.
Comment[bg]=Инструмент за изнасяне или внасяне на изображения от отдалечена директория, достъпна през KIO.
Comment[bs]=Alat za izvoz slika na udaljeni direktorij ili uvoz slika sa udaljenog direktorija koji je vidljiv sa KIO.
Comment[ca]=Una eina per exportar imatges o importar imatges des d'un directori remot que sigui accessible via KIO.
Comment[ca@valencia]=Una eina per exportar imatges o importar imatges des d'un directori remot que siga accessible via KIO.
Comment[cs]=Nástroj pro export nebo import obrázků ze vzdálené složky dostupné pomocí KIO.
Comment[da]=Et værktøj til at eksportere billeder til, eller importere fra, en ekstern mappe som er tilgængelig via KIO.
Comment[el]=Εργαλείο εικόνων για εξαγωγή σε ή εισαγωγή από έναν απομακρυσμένο κατάλογο με πρόσβαση από το KIO.
Comment[en_GB]=A tool to export pictures to or import from a remote directory that is accessible via KIO.
Comment[es]=Una herramienta para importar o exportar las imágenes desde/a un directorio remoto accesible vía KIO.
Comment[et]=Tööriist piltide eksportimiseks või importimiseks võrgukataloogi või võrgukataloogist KIO vahendusel.
Comment[eu]=Argazkiak esportatzeko edo urruneko direktorio batetik inportatzeko tresna bat (KIO bidez atzigarria).
Comment[fr]=Outil pour l'exportation ou l'importation vers le dossier à distance au travers des KIO
Comment[gl]=Unha ferramenta para exportar ou importar imaxes a un directorio remoto accesíbel a través de KIO.
Comment[hu]=Egy eszköz képek exportálásához vagy importálásához egy KIO által elérhető távoli könyvtárból.
Comment[is]=Verkfæri til að senda/flytja inn myndir frá fjarlægri möppu sem aðgengileg er með KIO.
Comment[it]=Uno strumento per esportare o importare immagini a o da una cartella remota accessibile con KIO.
Comment[km]=ឧបករណ៍​សម្រាប់​នាំ​ចេញ​រូបភាព​ទៅ ឬ​​ពី​ថតពី​ចម្ងាយ​ដែល​អាច​ចូល​ដំណើរ​ការ​បាន​តាម​រយៈ​ KIO ។
Comment[lv]=Rīks attēlu eksportēšanai uz vai importēšanai no attālas mapes, kas ir pieejama caur KIO.
Comment[nb]=Et verktøy for å eksportere bilder til eller importere fra en nettjeneste som KIO har tilgang til.
Comment[nl]=Een hulpmiddel om afbeeldingen te im- of exporteren uit een via KIO op afstand toegankelijke map.
Comment[pl]=Narzędzie do eksportowania zdjęć "do" lub importowania zdjęć "ze" zdalnego katalogu dostępnego przez KIO.
Comment[pt]=Uma ferramenta para exportar ou importar imagens para/de uma pasta remota que esteja acessível por KIO.
Comment[pt_BR]=Uma ferramenta para exportar imagens para ou importar de um diretório remoto que é acessível via KIO.
Comment[ro]=O unealtă de exportat imagini către sau de importat dintr-un director distant accesibil cu KIO.
Comment[ru]=Инструмент для экспорта/импорта в/из удалённый каталог, который доступен через KIO.
Comment[sk]=Nástroj na export do alebo na import zo vzdialeného priečinku, ktorý je dostupný pomocou KIO.
Comment[sl]=Orodje za izvoz slik ali uvoz iz oddaljene mape, ki je dostopna preko KIO.
Comment[sv]=Ett verktyg för att exportera bilder till eller importera från en fjärrkatalog tillgänglig via en I/O-slav.
Comment[th]=เครื่องมือส่งออกหรือนำเข้าภาพต่าง ๆ จากไดเรกทอรีทางไกล ที่สามารถเข้าใช้งานได้ผ่านทาง KIO
Comment[tr]=Resimleri KIO kullanarak uzak bir dizine aktarmak veya uzak dizinden içeriye aktarmak için bir araç.
Comment[uk]=Інструмент для експорту або імпорту зображень до віддалених каталогів, доступ до яких можна отримати за допомогою KIO.
Comment[x-test]=xxA tool to export pictures to or import from a remote directory that is accessible via KIO.xx
Comment[zh_CN]=一个通过 KIO 从远程目录导入图片或导出图片的工具。
Comment[zh_TW]=經由 KIO 匯出圖片到遠端可存取的目錄或從遠端可存取的目錄匯入圖片的工具。
Type=Service
Icon=folder-remote
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_kioexportimport
X-KIPI-PluginCategories=Export,Import
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Johannes Wienke, languitar at semipol dot de

==> digikam-4.0.0-beta2.tar.bz2: digikam-4.0.0-beta2/extra/kipi-plugins/kioexportimport/kipiplugin_kioexportimport.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=KioExportImport
Name=KioExportImport
Name[ast]=KioExportImport
Name[bg]=Изнасяне и внасяне през Kio
Name[bs]=Kio Izvoz Uvoz
Name[ca]=Exportador/Importador via KIO
Name[ca@valencia]=Exportador/Importador via KIO
Name[cs]=KioExportImport
Name[da]=KioExportImport
Name[de]=KioExportImport
Name[el]=KioExportImport
Name[en_GB]=KioExportImport
Name[es]=KioExportImport
Name[et]=KIO eksport-import
Name[eu]=KioExportImport
Name[fr]=Exportation / Importation vers un module d'entrées / sorties
Name[ga]=KioExportImport
Name[gl]=KioExportImport
Name[hu]=Kio exportálás-importálás
Name[is]=KioExportImport
Name[it]=Esportazione e importazione con KIO
Name[km]=KioExportImport
Name[lv]=KioExportImport
Name[nb]=KioExportImport
Name[nl]=KioExportImport
Name[pa]=KioExportImport
Name[pl]=EksportImportZKio
Name[pt]=KioExportImport
Name[pt_BR]=Exportar e importar pelo KIO
Name[ro]=Export/Import Kio
Name[ru]=Импорт и экспорт через KIO
Name[sk]=Kio export a import
Name[sl]=KioExportImport
Name[sv]=Export och import med I/O-slav
Name[th]=KioExportImport
Name[tr]=KioExportImport
Name[uk]=KioExportImport
Name[x-test]=xxKioExportImportxx
Name[zh_CN]=Kio 导入导出
Name[zh_TW]=Kio 匯出/匯入
Comment=A tool to export pictures to or import from a remote directory that is accessible via KIO.
Comment[bg]=Инструмент за изнасяне или внасяне на изображения от отдалечена директория, достъпна през KIO.
Comment[bs]=Alat za izvoz slika na udaljeni direktorij ili uvoz slika sa udaljenog direktorija koji je vidljiv sa KIO.
Comment[ca]=Una eina per exportar imatges o importar imatges des d'un directori remot que sigui accessible via KIO.
Comment[ca@valencia]=Una eina per exportar imatges o importar imatges des d'un directori remot que siga accessible via KIO.
Comment[cs]=Nástroj pro export nebo import obrázků ze vzdálené složky dostupné pomocí KIO.
Comment[da]=Et værktøj til at eksportere billeder til, eller importere fra, en ekstern mappe som er tilgængelig via KIO.
Comment[de]=Ein Werkzeug, um Bilder in einen entfernten Ordner, der mit Ein-/Ausgabemodul zu erreichen ist, zu exportieren oder von dort zu importieren..
Comment[el]=Εργαλείο εικόνων για εξαγωγή σε ή εισαγωγή από έναν απομακρυσμένο κατάλογο με πρόσβαση από το KIO.
Comment[en_GB]=A tool to export pictures to or import from a remote directory that is accessible via KIO.
Comment[es]=Una herramienta para importar o exportar las imágenes desde/a un directorio remoto accesible vía KIO.
Comment[et]=Tööriist piltide eksportimiseks või importimiseks võrgukataloogi või võrgukataloogist KIO vahendusel.
Comment[eu]=Argazkiak esportatzeko edo urruneko direktorio batetik inportatzeko tresna bat (KIO bidez atzigarria).
Comment[fr]=Outil d'exportation ou d'importation d'images vers ou à partir d'un dossier à distance accessible grâce à un module d'entrées / sorties
Comment[gl]=Unha ferramenta para exportar ou importar imaxes a un directorio remoto accesíbel a través de KIO.
Comment[hu]=Egy eszköz képek exportálásához vagy importálásához egy KIO által elérhető távoli könyvtárból.
Comment[is]=Verkfæri til að senda/flytja inn myndir frá fjarlægri möppu sem aðgengileg er með KIO.
Comment[it]=Uno strumento per esportare o importare immagini a o da una cartella remota accessibile con KIO.
Comment[km]=ឧបករណ៍​សម្រាប់​នាំ​ចេញ​រូបភាព​ទៅ ឬ​​ពី​ថតពី​ចម្ងាយ​ដែល​អាច​ចូល​ដំណើរ​ការ​បាន​តាម​រយៈ​ KIO ។
Comment[lv]=Rīks attēlu eksportēšanai uz vai importēšanai no attālas mapes, kas ir pieejama caur KIO.
Comment[nb]=Et verktøy for å eksportere bilder til eller importere fra en nettjeneste som KIO har tilgang til.
Comment[nl]=Een hulpmiddel om afbeeldingen te im- of exporteren uit een via KIO op afstand toegankelijke map.
Comment[pl]=Narzędzie do eksportowania zdjęć "do" lub importowania zdjęć "ze" zdalnego katalogu dostępnego przez KIO.
Comment[pt]=Uma ferramenta para exportar ou importar imagens para/de uma pasta remota que esteja acessível por KIO.
Comment[pt_BR]=Uma ferramenta para exportar imagens para ou importar de um diretório remoto que é acessível via KIO.
Comment[ro]=O unealtă de exportat imagini către sau de importat dintr-un director distant accesibil cu KIO.
Comment[ru]=Инструмент для экспорта/импорта в/из удалённый каталог, который доступен через KIO.
Comment[sk]=Nástroj na export do alebo na import zo vzdialeného priečinku, ktorý je dostupný pomocou KIO.
Comment[sl]=Orodje za izvoz slik ali uvoz iz oddaljene mape, ki je dostopna preko KIO.
Comment[sv]=Ett verktyg för att exportera bilder till eller importera från en fjärrkatalog tillgänglig via en I/O-slav.
Comment[th]=เครื่องมือส่งออกหรือนำเข้าภาพต่าง ๆ จากไดเรกทอรีทางไกล ที่สามารถเข้าใช้งานได้ผ่านทาง KIO
Comment[tr]=Resimleri KIO kullanarak uzak bir dizine aktarmak veya uzak dizinden içeriye aktarmak için bir araç.
Comment[uk]=Інструмент для експорту або імпорту зображень до віддалених каталогів, доступ до яких можна отримати за допомогою KIO.
Comment[x-test]=xxA tool to export pictures to or import from a remote directory that is accessible via KIO.xx
Comment[zh_CN]=一个通过 KIO 从远程目录导入图片或导出图片的工具。
Comment[zh_TW]=經由 KIO 匯出圖片到遠端可存取的目錄或從遠端可存取的目錄匯入圖片的工具。
Type=Service
Icon=folder-remote
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_kioexportimport
X-KIPI-PluginCategories=Export,Import
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Johannes Wienke, languitar at semipol dot de
